@@ -18,6 +18,7 @@
 
 
 #include "kgraphviewer.h"
+#include "kgraphviewer_debug.h"
 #include "part/kgraphviewer_interface.h"
 #include "kgraphviewerConfigDialog.h"
 #include "kgraphviewersettings.h"
@@ -27,28 +28,28 @@
 #include "ui_preferencesReopenPreviouslyOpenedFiles.h"
 
 #include <kshortcutsdialog.h>
-#include <kfiledialog.h>
+#include <QFileDialog>
 #include <kconfig.h>
-#include <kurl.h>
-#include <ktabwidget.h>
+#include <QUrl>
+#include <QTabWidget>
 #include <kparts/partmanager.h>
 #include <kedittoolbar.h>
-#include <kdebug.h>
-#include <kstandarddirs.h>
+#include <QDebug>
+#include <QStandardPaths>
 #include <kstandardaction.h>
 #include <ktoggleaction.h>
-#include <klibloader.h>
+#include <KService>
+#include <KPluginFactory>
 #include <kmessagebox.h>
-#include <kstatusbar.h>
-#include <klocale.h>
+#include <QStatusBar>
 #include <kconfigdialog.h>
-#include <kiconloader.h>
+#include <QIcon>
 #include <krecentfilesaction.h>
 #include <ktoolbar.h>
 #include <KActionCollection>
-
-#include <QtDBus/QtDBus>
-
+#include <klocalizedstring.h>
+#include <QDBusConnection>
+#include <KParts/ReadOnlyPart>
 #include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
@@ -56,37 +57,32 @@
 
 KGraphViewerWindow::KGraphViewerWindow()
     : KParts::MainWindow(),
-      m_rfa(0)
+      m_rfa(nullptr)
 {
   // set the shell's ui resource file
   setXMLFile("kgraphviewerui.rc");
 
 //   std::cerr << "Creating tab widget" << std::endl;
-  m_widget = new KTabWidget(this);
-  m_widget->setHoverCloseButton(true);
-  connect(m_widget, SIGNAL(closeRequest(QWidget*)), this, SLOT(close(QWidget*)));
-  connect(m_widget, SIGNAL(currentChanged(QWidget*)), this, SLOT(newTabSelectedSlot(QWidget*)));
+  m_widget = new QTabWidget(this);
+  m_widget->setTabsClosable(true);
+  connect(m_widget, &QTabWidget::tabCloseRequested,
+          this, static_cast<void(KGraphViewerWindow::*)(int)>(&KGraphViewerWindow::close));
+  connect(m_widget, &QTabWidget::currentChanged,
+          this, &KGraphViewerWindow::newTabSelectedSlot);
   
   setCentralWidget(m_widget);
   
   if (QDBusConnection::sessionBus().registerService( "org.kde.kgraphviewer" ))
   {
-    kDebug() << "Service Registered successfully";
+    qCDebug(KGRAPHVIEWER_LOG) << "Service Registered successfully";
     QDBusConnection::sessionBus().registerObject("/", this, QDBusConnection::ExportAllSlots);
     
   }
   else
   {
-    kDebug() << "Failed to register service...";
+    qCDebug(KGRAPHVIEWER_LOG) << "Failed to register service...";
   }
 
-  // then, setup our actions
-  setupActions();
-
-  // and a status bar
-  statusBar()->show();
-  createStandardStatusBarAction();
-
   // this routine will find and load our Part.  it finds the Part by
   // name which is a bad idea usually.. but it's alright in this
   // case since our Part is made for this Shell
@@ -95,23 +91,26 @@ KGraphViewerWindow::KGraphViewerWindow()
   m_manager = new KParts::PartManager( this );
   
   // When the manager says the active part changes, the window updates (recreates) the GUI
-  connect( m_manager, SIGNAL(activePartChanged(KParts::Part*)),
-           this, SLOT(createGUI(KParts::Part*)) );
-    
+  connect(m_manager, &KParts::PartManager::activePartChanged,
+          this, &KGraphViewerWindow::createGUI);
+
+  setupGUI(ToolBar | Keys | StatusBar | Save);
+
+  // then, setup our actions
+  setupActions();
+
   // Creates the GUI with a null part to make appear the main app menus and tools
-  createGUI(0);
-  setupGUI();  
-  // apply the saved mainwindow settings, if any, and ask the mainwindow
-  // to automatically save settings if changed: window size, toolbar
-  // position, icon size, etc.
-  setAutoSaveSettings();
+  createGUI(nullptr);
 }
 
 KGraphViewerWindow::~KGraphViewerWindow()
 {
-  KSharedConfig::Ptr config = KGlobal::config();
-  if (m_rfa != 0)
+  KSharedConfig::Ptr config = KSharedConfig::openConfig();
+  if (m_rfa)
     m_rfa->saveEntries(KConfigGroup(config, "kgraphviewer recent files"));
+
+  // delete partsmanager explicitly, to avoid activePartChanged being emitted from here
+  delete m_manager;
 }
 
 void KGraphViewerWindow::reloadPreviousFiles()
@@ -131,31 +130,31 @@ void KGraphViewerWindow::reloadPreviousFiles()
     {
       openUrl(*it);
     }
-    KGraphViewerSettings::self()->writeConfig();
+    KGraphViewerSettings::self()->save();
   }
   
 }
 
-void KGraphViewerWindow::openUrl(const KUrl& url)
+void KGraphViewerWindow::openUrl(const QUrl& url)
 {
-  kDebug() << url;
+  qCDebug(KGRAPHVIEWER_LOG) << url;
   KPluginFactory *factory = KPluginLoader("kgraphviewerpart").factory();
   if (!factory)
   {
     // if we couldn't find our Part, we exit since the Shell by
     // itself can't do anything useful
     KMessageBox::error(this, i18n("Could not find the KGraphViewer part."));
-    kapp->quit();
+    qApp->quit();
     // we return here, cause kapp->quit() only means "exit the
     // next time we enter the event loop...
     return;
   }
-    KParts::ReadOnlyPart* part = factory->create<KParts::ReadOnlyPart>("kgraphviewerpart", this);
+    KParts::ReadOnlyPart* part = factory->create<KParts::ReadOnlyPart>(this);
     KGraphViewer::KGraphViewerInterface* kgv = qobject_cast<KGraphViewer::KGraphViewerInterface*>( part );
     if( ! kgv )
     {
       // This should not happen
-      kError() << "Failed to get KPart" << endl;
+      qCWarning(KGRAPHVIEWER_LOG) << "Failed to get KPart" << endl;
       return;
     }
     kgv->setBackgroundColor(KGraphViewerSettings::backgroundColor());
@@ -166,90 +165,94 @@ void KGraphViewerWindow::openUrl(const KUrl& url)
     if (part)
     {
       QString fileName = url.url();
-      QString label = fileName.section('/',-1,-1);
       QWidget *w = part->widget();
-      m_widget->addTab(w, QIcon( DesktopIcon("kgraphviewer") ), label);
-      m_widget->setCurrentWidget(w);
-      createGUI(part);
 
       part->openUrl( url );
       
-      if (m_rfa != 0)
+      if (m_rfa)
       {
         m_rfa->addUrl(url);
-        KSharedConfig::Ptr config = KGlobal::config();
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
         m_rfa->saveEntries(KConfigGroup(config, "kgraphviewer recent files"));
       }
 
       m_openedFiles.push_back(fileName);
-      m_manager->addPart( part, true );
       m_tabsPartsMap[w] = part;
       m_tabsFilesMap[w] = fileName;
       connect(this,SIGNAL(hide(KParts::Part*)),part,SLOT(slotHide(KParts::Part*)));
-      connect(part,SIGNAL(close()),this,SLOT(close()));
 
-      connect(part, SIGNAL(hoverEnter(QString)), this, SLOT(slotHoverEnter(QString)));
-      connect(part, SIGNAL(hoverLeave(QString)), this, SLOT(slotHoverLeave(QString)));
+      connect(part, SIGNAL(hoverEnter(QString)),
+              this, SLOT(slotHoverEnter(QString)));
+      connect(part, SIGNAL(hoverLeave(QString)),
+              this, SLOT(slotHoverLeave(QString)));
+
+      m_manager->addPart( part, true );
+      const QString label = fileName.section('/', -1, -1);
+      m_widget->addTab(w, QIcon::fromTheme("kgraphviewer"), label);
+      m_widget->setCurrentWidget(w);
+      m_closeAction->setEnabled(true);
     }
 }
 
 void KGraphViewerWindow::fileOpen()
 {
-  kDebug() ;
+  qCDebug(KGRAPHVIEWER_LOG) ;
   // this slot is called whenever the File->Open menu is selected,
   // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
   // button is clicked
-  QStringList file_names = KFileDialog::getOpenFileNames(KUrl(QString()), QString("*.dot"), 0, QString());
-  
-  if (!file_names.empty())
-  {
-    QStringList::const_iterator it, it_end;
-    it = file_names.constBegin(); it_end = file_names.constEnd();
-    for (; it != it_end; it++)
-    {
-      openUrl(*it);
-    }
+  QFileDialog fileDialog(this);
+  fileDialog.setMimeTypeFilters(QStringList(QStringLiteral("text/vnd.graphviz")));
+  fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
+  fileDialog.setFileMode(QFileDialog::ExistingFiles);
+  if (fileDialog.exec() != QFileDialog::Accepted) {
+    return;
+  }
+
+  foreach (const QUrl& url, fileDialog.selectedUrls()) {
+    openUrl(url);
   }
 }
 
 void KGraphViewerWindow::setupActions()
 {
   // create our actions
-  KAction* newAction = actionCollection()->addAction( KStandardAction::New, "file_new", this, SLOT(fileNew()) );
+  QAction* newAction = actionCollection()->addAction( KStandardAction::New, "file_new", this, SLOT(fileNew()) );
   newAction->setWhatsThis(i18n("Opens a new empty KGraphViewer window."));
   
-  KAction* openAction = actionCollection()->addAction( KStandardAction::Open, "file_open", this, SLOT(fileOpen()) );
-  openAction->setWhatsThis(i18n("Shows the file open dialog to choose a GraphViz dot file to open."));
+  QAction* openAction = actionCollection()->addAction( KStandardAction::Open, "file_open", this, SLOT(fileOpen()) );
+  openAction->setWhatsThis(i18n("Shows the file open dialog to choose a Graphviz DOT file to open."));
   
-  m_rfa = KStandardAction::openRecent(this, SLOT(slotURLSelected(KUrl)), this);
+  m_rfa = KStandardAction::openRecent(this, SLOT(slotURLSelected(QUrl)), this);
   actionCollection()->addAction(m_rfa->objectName(),m_rfa);
   m_rfa->setWhatsThis(i18n("This lists files which you have opened recently, and allows you to easily open them again."));
 
-  KSharedConfig::Ptr config = KGlobal::config();
+  KSharedConfig::Ptr config = KSharedConfig::openConfig();
   m_rfa->loadEntries(KConfigGroup(config, "kgraphviewer recent files"));
   
-  KAction* quitAction = actionCollection()->addAction( KStandardAction::Quit, "file_quit", KApplication::kApplication(), SLOT(quit()) );
+  m_closeAction = actionCollection()->addAction( KStandardAction::Close, "file_close", this, SLOT(close()) );
+  m_closeAction->setWhatsThis(i18n("Closes the current file"));
+  m_closeAction->setEnabled(false);
+
+  QAction* quitAction = actionCollection()->addAction( KStandardAction::Quit, "file_quit", qApp, SLOT(quit()) );
   quitAction->setWhatsThis(i18n("Quits KGraphViewer."));
   
   m_statusbarAction = KStandardAction::showStatusbar(this, SLOT(optionsShowStatusbar()), this);
   m_statusbarAction->setWhatsThis(i18n("Shows or hides the status bar."));
   
-  KAction* kbAction = actionCollection()->addAction( KStandardAction::KeyBindings, "options_configure_keybinding", this, SLOT(optionsConfigureKeys()) );
+  QAction* kbAction = actionCollection()->addAction( KStandardAction::KeyBindings, "options_configure_keybinding", this, SLOT(optionsConfigureKeys()) );
   kbAction->setWhatsThis(i18n("Configure the bindings between keys and actions."));
   
-  KAction* ctAction = actionCollection()->addAction( KStandardAction::ConfigureToolbars, "options_configure_toolbars", this, SLOT(optionsConfigureToolbars()) );
+  QAction* ctAction = actionCollection()->addAction( KStandardAction::ConfigureToolbars, "options_configure_toolbars", this, SLOT(optionsConfigureToolbars()) );
   ctAction->setWhatsThis(i18n("Toolbar configuration."));
   
-  KAction* configureAction = actionCollection()->addAction( KStandardAction::Preferences, "options_configure", this, SLOT(optionsConfigure()) );
+  QAction* configureAction = actionCollection()->addAction( KStandardAction::Preferences, "options_configure", this, SLOT(optionsConfigure()) );
   configureAction->setWhatsThis(i18n("Main KGraphViewer configuration options."));
-  
-
 }
 
 void KGraphViewerWindow::closeEvent(QCloseEvent* event)
 {
   KGraphViewerSettings::setPreviouslyOpenedFiles(m_openedFiles);
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
   KParts::MainWindow::closeEvent(event);
 }
 
@@ -290,12 +293,13 @@ void KGraphViewerWindow::optionsConfigureKeys()
 
 void KGraphViewerWindow::optionsConfigureToolbars()
 {
-    saveMainWindowSettings(KGlobal::config()->group("kgraphviewer") );
+  KConfigGroup group(KConfigGroup(KSharedConfig::openConfig(), "kgraphviewer"));
+  KMainWindow::saveMainWindowSettings(group);
 
   // use the standard toolbar editor
   KEditToolBar dlg(factory());
-  connect(&dlg, SIGNAL(newToolbarConfig()),
-          this, SLOT(applyNewToolbarConfig()));
+  connect(&dlg, &KEditToolBar::newToolbarConfig,
+          this, &KGraphViewerWindow::applyNewToolbarConfig);
   dlg.exec();
 }
 
@@ -308,12 +312,11 @@ void KGraphViewerWindow::optionsConfigure()
     return; 
  
   //KConfigDialog didn't find an instance of this dialog, so lets create it : 
-  KPageDialog::FaceType ft = KPageDialog::Auto;
-  KgvConfigurationDialog* dialog = new KgvConfigurationDialog( this, "settings", 
-                                             KGraphViewerSettings::self(),ft ); 
-  connect(dialog,SIGNAL(backgroundColorChanged(QColor)),this,SLOT(slotBackgroundColorChanged(QColor)));
+  KgvConfigurationDialog* dialog = new KgvConfigurationDialog( this, "settings", KGraphViewerSettings::self());
+  connect(dialog, &KgvConfigurationDialog::backgroundColorChanged,
+          this, &KGraphViewerWindow::slotBackgroundColorChanged);
   Ui::KGraphViewerPreferencesParsingWidget*  parsingWidget = dialog->parsingWidget;
-  kDebug() << KGraphViewerSettings::parsingMode();
+  qCDebug(KGRAPHVIEWER_LOG) << KGraphViewerSettings::parsingMode();
   if (KGraphViewerSettings::parsingMode() == "external")
   {
     parsingWidget->external->setChecked(true);
@@ -322,11 +325,13 @@ void KGraphViewerWindow::optionsConfigure()
   {
     parsingWidget->internal->setChecked(true);
   }
-  connect((QObject*)parsingWidget->external, SIGNAL(toggled(bool)), this, SLOT(slotParsingModeExternalToggled(bool)) );
-  connect((QObject*)parsingWidget->internal, SIGNAL(toggled(bool)), this, SLOT(slotParsingModeInternalToggled(bool)) );
+  connect(parsingWidget->external, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotParsingModeExternalToggled);
+  connect(parsingWidget->internal, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotParsingModeInternalToggled);
 
   Ui::KGraphViewerPreferencesReloadWidget*  reloadWidget = dialog->reloadWidget;
-  kDebug() << KGraphViewerSettings::reloadOnChangeMode();
+  qCDebug(KGRAPHVIEWER_LOG) << KGraphViewerSettings::reloadOnChangeMode();
   if (KGraphViewerSettings::reloadOnChangeMode() == "true")
   {
     reloadWidget->yes->setChecked(true);
@@ -340,9 +345,12 @@ void KGraphViewerWindow::optionsConfigure()
     reloadWidget->ask->setChecked(true);
   }
   
-  connect((QObject*)reloadWidget->yes, SIGNAL(toggled(bool)), this, SLOT(slotReloadOnChangeModeYesToggled(bool)) );
-  connect((QObject*)reloadWidget->no, SIGNAL(toggled(bool)), this, SLOT(slotReloadOnChangeModeNoToggled(bool)) );
-  connect((QObject*)reloadWidget->ask, SIGNAL(toggled(bool)), this, SLOT(slotReloadOnChangeModeAskToggled(bool)) );
+  connect(reloadWidget->yes, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReloadOnChangeModeYesToggled);
+  connect(reloadWidget->no, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReloadOnChangeModeNoToggled);
+  connect(reloadWidget->ask, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReloadOnChangeModeAskToggled);
 
   Ui::KGraphViewerPreferencesOpenInExistingWindowWidget*  openingWidget = dialog->openingWidget;
   if (KGraphViewerSettings::openInExistingWindowMode() == "true")
@@ -358,9 +366,12 @@ void KGraphViewerWindow::optionsConfigure()
     openingWidget->ask->setChecked(true);
   }
   
-  connect((QObject*)openingWidget->yes, SIGNAL(toggled(bool)), this, SLOT(slotOpenInExistingWindowModeYesToggled(bool)) );
-  connect((QObject*)openingWidget->no, SIGNAL(toggled(bool)), this, SLOT(slotOpenInExistingWindowModeNoToggled(bool)) );
-  connect((QObject*)openingWidget->ask, SIGNAL(toggled(bool)), this, SLOT(slotOpenInExistingWindowModeAskToggled(bool)) );
+  connect(openingWidget->yes, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotOpenInExistingWindowModeYesToggled);
+  connect(openingWidget->no, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotOpenInExistingWindowModeNoToggled);
+  connect(openingWidget->ask, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotOpenInExistingWindowModeAskToggled);
   
   Ui::KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget*  reopeningWidget = dialog->reopeningWidget;
   if (KGraphViewerSettings::reopenPreviouslyOpenedFilesMode() == "true")
@@ -376,197 +387,198 @@ void KGraphViewerWindow::optionsConfigure()
     reopeningWidget->ask->setChecked(true);
   }
   
-  connect((QObject*)reopeningWidget->yes, SIGNAL(toggled(bool)), this, SLOT(slotReopenPreviouslyOpenedFilesModeYesToggled(bool)) );
-  connect((QObject*)reopeningWidget->no, SIGNAL(toggled(bool)), this, SLOT(slotReopenPreviouslyOpenedFilesModeNoToggled(bool)) );
-  connect((QObject*)reopeningWidget->ask, SIGNAL(toggled(bool)), this, SLOT(slotReopenPreviouslyOpenedFilesModeAskToggled(bool)) );
+  connect(reopeningWidget->yes, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeYesToggled);
+  connect(reopeningWidget->no, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeNoToggled);
+  connect(reopeningWidget->ask, &QRadioButton::toggled,
+          this, &KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeAskToggled);
   
-  connect(dialog, SIGNAL(settingsChanged()), this, SLOT(settingsChanged()));
-
   dialog->show();
 }
 
 void KGraphViewerWindow::applyNewToolbarConfig()
 {
-  applyMainWindowSettings(KGlobal::config()->group("kgraphviewer"));
+  applyMainWindowSettings(KSharedConfig::openConfig()->group("kgraphviewer"));
 }
 
 void KGraphViewerWindow::slotReloadOnChangeModeYesToggled(bool value)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   if (value)
   {
     KGraphViewerSettings::setReloadOnChangeMode("true");
   }
-  //   kDebug() << "emitting";
+  //   qCDebug(KGRAPHVIEWER_LOG) << "emitting";
   //   emit(settingsChanged());
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotReloadOnChangeModeNoToggled(bool value)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   if (value)
   {
     KGraphViewerSettings::setReloadOnChangeMode("false");
   }
-  //   kDebug() << "emitting";
+  //   qCDebug(KGRAPHVIEWER_LOG) << "emitting";
   //   emit(settingsChanged());
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotReloadOnChangeModeAskToggled(bool value)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   if (value)
   {
     KGraphViewerSettings::setReloadOnChangeMode("ask");
   }
-  //   kDebug() << "emitting";
+  //   qCDebug(KGRAPHVIEWER_LOG) << "emitting";
   //   emit(settingsChanged());
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotOpenInExistingWindowModeYesToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setOpenInExistingWindowMode("true");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotOpenInExistingWindowModeNoToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setOpenInExistingWindowMode("false");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotOpenInExistingWindowModeAskToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setOpenInExistingWindowMode("ask");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeYesToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setReopenPreviouslyOpenedFilesMode("true");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeNoToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setReopenPreviouslyOpenedFilesMode("false");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotReopenPreviouslyOpenedFilesModeAskToggled(bool value)
 {
-  kDebug() << value;
+  qCDebug(KGRAPHVIEWER_LOG) << value;
   if (value)
   {
     KGraphViewerSettings::setReopenPreviouslyOpenedFilesMode("ask");
   }
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotParsingModeExternalToggled(bool value)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   if (value)
   {
     KGraphViewerSettings::setParsingMode("external");
   }
-  //   kDebug() << "emitting";
+  //   qCDebug(KGRAPHVIEWER_LOG) << "emitting";
   //   emit(settingsChanged());
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 void KGraphViewerWindow::slotParsingModeInternalToggled(bool value)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   if (value)
   {
     KGraphViewerSettings::setParsingMode("internal");
   }
-  //   kDebug() << "emitting";
+  //   qCDebug(KGRAPHVIEWER_LOG) << "emitting";
   //   emit(settingsChanged());
-  KGraphViewerSettings::self()->writeConfig();
+  KGraphViewerSettings::self()->save();
 }
 
 
 
-void KGraphViewerWindow::slotURLSelected(const KUrl& url)
+void KGraphViewerWindow::slotURLSelected(const QUrl& url)
 {
   openUrl(url);
 }
 
-void KGraphViewerWindow::close(QWidget* tab)
+void KGraphViewerWindow::close(int index)
 {
-  kDebug() << tab;
+  QWidget *tab = m_widget->widget(index);
   m_openedFiles.removeAll(m_tabsFilesMap[tab]);
-  m_widget->removePage(tab);
+  m_widget->removeTab(index);
   tab->hide();
   KParts::Part* part = m_tabsPartsMap[tab];
   m_manager->removePart(part);
   m_tabsPartsMap.remove(tab);
   m_tabsFilesMap.remove(tab);
-  delete part; part=0;
+  delete part; part = nullptr;
 /*  delete tab;
-  tab = 0;*/
+  tab = nullptr;*/
+  m_closeAction->setEnabled(m_widget->count() > 0);
 }
 
 void KGraphViewerWindow::close()
 {
-  kDebug();
-  QWidget* currentPage = m_widget->currentWidget();
-  if (currentPage != 0)
+  int currentPage = m_widget->currentIndex();
+  if (currentPage != -1)
   {
     close(currentPage);
   }
 }
 
-void KGraphViewerWindow::newTabSelectedSlot(QWidget* tab)
+void KGraphViewerWindow::newTabSelectedSlot(int index)
 {
-  kDebug() << tab;
   emit(hide((KParts::Part*)(m_manager->activePart())));
-  if (!m_tabsPartsMap.isEmpty())
-  {
+
+  QWidget *tab = m_widget->widget(index);
+  if (tab) {
     m_manager->setActivePart(m_tabsPartsMap[tab]);
   }
 }
 
 void KGraphViewerWindow::slotHoverEnter(const QString& id)
 {
-  kDebug() << id;
+  qCDebug(KGRAPHVIEWER_LOG) << id;
   statusBar()->showMessage(id);
 }
 
 void KGraphViewerWindow::slotHoverLeave(const QString& id)
 {
-  kDebug() << id;
+  qCDebug(KGRAPHVIEWER_LOG) << id;
   statusBar()->showMessage("");
 }
 
 void KGraphViewerWindow::slotBackgroundColorChanged(const QColor&)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWER_LOG);
   foreach(KParts::Part* part, m_tabsPartsMap)
   {
     KGraphViewer::KGraphViewerInterface* kgv = qobject_cast<KGraphViewer::KGraphViewerInterface*>( part );
@@ -578,5 +590,3 @@ void KGraphViewerWindow::slotBackgroundColorChanged(const QColor&)
     kgv->setBackgroundColor(KGraphViewerSettings::backgroundColor());
   }
 }
-
-#include "kgraphviewer.moc"
