@@ -23,7 +23,7 @@
 #include "canvasedge.h"
 #include "canvassubgraph.h"
 #include "layoutagraphthread.h"
-
+#include "kgraphviewerlib_debug.h"
 
 #include <iostream>
 #include <stdio.h>
@@ -32,8 +32,7 @@
 #include <boost/spirit/include/classic_confix.hpp>
 #include <graphviz/gvc.h>
 
-#include <kdebug.h>
-#include <KMessageBox>
+#include <QMessageBox>
 
 #include <QFile>
 #include <QPair>
@@ -41,6 +40,7 @@
 #include <QProcess>
 #include <QMutexLocker>
 #include <QUuid>
+#include <klocalizedstring.h>
 
 using namespace boost;
 using namespace boost::spirit::classic;
@@ -62,7 +62,7 @@ DotGraph::DotGraph() :
   m_horizCellFactor(0), m_vertCellFactor(0),
   m_wdhcf(0), m_hdvcf(0),
   m_readWrite(false),
-  m_dot(0),
+  m_dot(nullptr),
   m_phase(Initial),
   m_useLibrary(false)
 {
@@ -77,7 +77,7 @@ DotGraph::DotGraph(const QString& command, const QString& fileName) :
   m_horizCellFactor(0), m_vertCellFactor(0),
   m_wdhcf(0), m_hdvcf(0),
   m_readWrite(false),
-  m_dot(0),
+  m_dot(nullptr),
   m_phase(Initial),
   m_useLibrary(false)
 {
@@ -100,7 +100,7 @@ QString DotGraph::chooseLayoutProgramForFile(const QString& str)
 
   if (!iFILE.open(QIODevice::ReadOnly))
   {
-    kError() << "Can't test dot file. Will try to use the dot command on the file: '" << str << "'" << endl;
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "Can't test dot file. Will try to use the dot command on the file: '" << str << "'" << endl;
     return "dot";// -Txdot";
   }
 
@@ -118,7 +118,7 @@ QString DotGraph::chooseLayoutProgramForFile(const QString& str)
 
 bool DotGraph::parseDot(const QString& str)
 {
-  kDebug() << str;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << str;
   m_useLibrary = false;
   if (m_layoutCommand.isEmpty())
   {
@@ -130,7 +130,7 @@ bool DotGraph::parseDot(const QString& str)
     }
   }
 
-  kDebug() << "Running " << m_layoutCommand  << str;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "Running " << m_layoutCommand  << str;
   QStringList options;
   /// @TODO handle the non-dot commands that could don't know the -T option
 //  if (m_readWrite && m_phase == Initial)
@@ -143,21 +143,22 @@ bool DotGraph::parseDot(const QString& str)
 //   }
   options << str;
 
-  kDebug() << "m_dot is " << m_dot  << ". Acquiring mutex";
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "m_dot is " << m_dot  << ". Acquiring mutex";
   QMutexLocker locker(&m_dotProcessMutex);
-  kDebug() << "mutex acquired ";
-  if (m_dot != 0)
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "mutex acquired ";
+  if (m_dot)
   {
-    disconnect(m_dot,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(slotDotRunningDone(int,QProcess::ExitStatus)));
-    disconnect(m_dot,SIGNAL(error(QProcess::ProcessError)),this,SLOT(slotDotRunningError(QProcess::ProcessError)));
+    disconnect(m_dot, nullptr, this, nullptr);
     m_dot->kill();
     delete m_dot;
   }
   m_dot = new QProcess();
-  connect(m_dot,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(slotDotRunningDone(int,QProcess::ExitStatus)));
-  connect(m_dot,SIGNAL(error(QProcess::ProcessError)),this,SLOT(slotDotRunningError(QProcess::ProcessError)));
+  connect(m_dot, static_cast<void(QProcess::*)(int,QProcess::ExitStatus)>(&QProcess::finished),
+          this, &DotGraph::slotDotRunningDone);
+  connect(m_dot, static_cast<void(QProcess::*)(QProcess::ProcessError)>(&QProcess::error),
+          this, &DotGraph::slotDotRunningError);
   m_dot->start(m_layoutCommand, options);
-  kDebug() << "process started";
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "process started";
  return true;
 }
 
@@ -166,18 +167,18 @@ bool DotGraph::update()
   GraphExporter exporter;
   if (!m_useLibrary)
   {
-    kDebug() << "command";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "command";
     QString str = exporter.writeDot(this);
     return parseDot(str);
   }
   else
   {
-    kDebug() << "library";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "library";
     graph_t* graph = exporter.exportToGraphviz(this);
 
     GVC_t* gvc = gvContext();
     threadsafe_wrap_gvLayout(gvc, graph, m_layoutCommand.toUtf8().data());
-    threadsafe_wrap_gvRender(gvc, graph, "xdot", NULL);
+    threadsafe_wrap_gvRender(gvc, graph, "xdot", nullptr);
 
     updateWithGraph(graph);
     
@@ -190,32 +191,32 @@ bool DotGraph::update()
 
 QByteArray DotGraph::getDotResult(int , QProcess::ExitStatus )
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWERLIB_LOG);
 
   QMutexLocker locker(&m_dotProcessMutex);
-  if (m_dot == 0)
+  if (m_dot == nullptr)
   {
     return QByteArray();
   }
   QByteArray result = m_dot->readAll();
   delete m_dot;
-  m_dot = 0;
+  m_dot = nullptr;
   return result;
 }
 
 void DotGraph::slotDotRunningDone(int exitCode, QProcess::ExitStatus exitStatus)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWERLIB_LOG);
   
   QByteArray result = getDotResult(exitCode, exitStatus);
   result.replace("\\\n","");
 
-  kDebug() << "string content is:" << endl << result << endl << "=====================" << result.size();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "string content is:" << endl << result << endl << "=====================" << result.size();
   std::string s =  result.data();
   //   std::cerr << "stdstring content is:" << std::endl << s << std::endl << "===================== " << s.size() << std::endl;
-  if (phelper != 0)
+  if (phelper)
   {
-    phelper->graph = 0;
+    phelper->graph = nullptr;
     delete phelper;
   }
 //   if (parsingResult)
@@ -235,21 +236,20 @@ void DotGraph::slotDotRunningDone(int exitCode, QProcess::ExitStatus exitStatus)
   phelper->maxZ = 1;
   phelper->uniq = 0;
 
-  kDebug() << "parsing new dot";
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "parsing new dot";
   bool parsingResult = parse(s);
   delete phelper;
-  phelper = 0;
-  kDebug() << "phelper deleted";
+  phelper = nullptr;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "phelper deleted";
 
   if (parsingResult)
   {
-    kDebug() << "calling updateWithGraph";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "calling updateWithGraph";
     updateWithGraph(newGraph);
   }
   else
   {
-    kDebug() << "parsing failed";
-    kError() << "parsing failed";
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "parsing failed";
   }
 //   return parsingResult;
 //   if (m_readWrite && m_phase == Initial)
@@ -259,45 +259,45 @@ void DotGraph::slotDotRunningDone(int exitCode, QProcess::ExitStatus exitStatus)
 //   }
 //   else
 //   {
-    kDebug() << "emiting readyToDisplay";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "emiting readyToDisplay";
     emit(readyToDisplay());
 //   }
 }
 
 void DotGraph::slotDotRunningError(QProcess::ProcessError error)
 {
-  kError() << "DotGraph::slotDotRunningError" << error;
+  qCWarning(KGRAPHVIEWERLIB_LOG) << "DotGraph::slotDotRunningError" << error;
   switch (error)
   {
     case QProcess::FailedToStart:
-      KMessageBox::error(0, i18n("Unable to start %1.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("Unable to start %1.", m_layoutCommand));
     break;
     case QProcess::Crashed:
-      KMessageBox::error(0, i18n("%1 crashed.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("%1 crashed.", m_layoutCommand));
     break;
     case QProcess::Timedout:
-      KMessageBox::error(0, i18n("%1 timed out.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("%1 timed out.", m_layoutCommand));
     break;
     case QProcess::WriteError:
-      KMessageBox::error(0, i18n("Was not able to write data to the %1 process.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("Was not able to write data to the %1 process.", m_layoutCommand));
     break;
     case QProcess::ReadError:
-      KMessageBox::error(0, i18n("Was not able to read data from the %1 process.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("Was not able to read data from the %1 process.", m_layoutCommand));
     break;
     default:
-      KMessageBox::error(0, i18n("Unknown error running %1.", m_layoutCommand),i18n("Layout process failed"),KMessageBox::Notify);
+      QMessageBox::critical(nullptr, i18n("Layout process failed"), i18n("Unknown error running %1.", m_layoutCommand));
   }
 }
 
 unsigned int DotGraph::cellNumber(int x, int y)
 {
-/*  kDebug() << "x= " << x << ", y= " << y << ", m_width= " << m_width << ", m_height= " << m_height << ", m_horizCellFactor= " << m_horizCellFactor << ", m_vertCellFactor= " << m_vertCellFactor  << ", m_wdhcf= " << m_wdhcf << ", m_hdvcf= " << m_hdvcf;*/
+/*  qCDebug(KGRAPHVIEWERLIB_LOG) << "x= " << x << ", y= " << y << ", m_width= " << m_width << ", m_height= " << m_height << ", m_horizCellFactor= " << m_horizCellFactor << ", m_vertCellFactor= " << m_vertCellFactor  << ", m_wdhcf= " << m_wdhcf << ", m_hdvcf= " << m_hdvcf;*/
   
   unsigned int nx = (unsigned int)(( x - ( x % int(m_wdhcf) ) ) / m_wdhcf);
   unsigned int ny = (unsigned int)(( y - ( y % int(m_hdvcf) ) ) / m_hdvcf);
-/*  kDebug() << "nx = " << (unsigned int)(( x - ( x % int(m_wdhcf) ) ) / m_wdhcf);
-  kDebug() << "ny = " << (unsigned int)(( y - ( y % int(m_hdvcf) ) ) / m_hdvcf);
-  kDebug() << "res = " << ny * m_horizCellFactor + nx;*/
+/*  qCDebug(KGRAPHVIEWERLIB_LOG) << "nx = " << (unsigned int)(( x - ( x % int(m_wdhcf) ) ) / m_wdhcf);
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "ny = " << (unsigned int)(( y - ( y % int(m_hdvcf) ) ) / m_hdvcf);
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "res = " << ny * m_horizCellFactor + nx;*/
   
   unsigned int res = ny * m_horizCellFactor + nx;
   return res;
@@ -308,7 +308,7 @@ unsigned int DotGraph::cellNumber(int x, int y)
 void DotGraph::computeCells()
 {
   return;
-  kDebug() << m_width << m_height << endl;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << m_width << m_height << endl;
   m_horizCellFactor = m_vertCellFactor = 1;
   m_wdhcf = (int)ceil(((double)m_width) / m_horizCellFactor)+1;
   m_hdvcf = (int)ceil(((double)m_height) / m_vertCellFactor)+1;
@@ -326,7 +326,7 @@ void DotGraph::computeCells()
       GraphNode* gn = *it;
 //       int cellNum = cellNumber(int(gn->x()), int(gn->y()));
       int cellNum = cellNumber(0,0);
-      kDebug() << "Found cell number " << cellNum;
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "Found cell number " << cellNum;
 
       if (m_cells.size() <= cellNum)
       {
@@ -334,10 +334,10 @@ void DotGraph::computeCells()
       }
       m_cells[cellNum].insert(gn);
       
-      kDebug() << "after insert";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "after insert";
       if ( m_cells[cellNum].size() > MAXCELLWEIGHT )
       {
-        kDebug() << "cell number " << cellNum  << " contains " << m_cells[cellNum].size() << " nodes";
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "cell number " << cellNum  << " contains " << m_cells[cellNum].size() << " nodes";
         if ((m_width/m_horizCellFactor) > (m_height/m_vertCellFactor))
         {
           m_horizCellFactor++;
@@ -348,14 +348,14 @@ void DotGraph::computeCells()
           m_vertCellFactor++;
           m_hdvcf = m_height / m_vertCellFactor;
         }
-        kDebug() << "cell factor is now " << m_horizCellFactor << " / " << m_vertCellFactor;
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "cell factor is now " << m_horizCellFactor << " / " << m_vertCellFactor;
         stop = false;
         break;
       }
     }
   } while (!stop);
-  kDebug() << "m_wdhcf=" << m_wdhcf << "; m_hdvcf=" << m_hdvcf << endl;
-  kDebug() << "finished" << endl;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "m_wdhcf=" << m_wdhcf << "; m_hdvcf=" << m_hdvcf << endl;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "finished" << endl;
 }
 
 QSet< GraphNode* >& DotGraph::nodesOfCell(unsigned int id)
@@ -382,7 +382,7 @@ void DotGraph::storeOriginalAttributes()
 
 void DotGraph::saveTo(const QString& fileName)
 {
-  kDebug() << fileName;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << fileName;
   m_dotFileName = fileName;
   GraphExporter exporter;
   exporter.writeDot(this, fileName);
@@ -390,30 +390,30 @@ void DotGraph::saveTo(const QString& fileName)
 
 void DotGraph::updateWithGraph(graph_t* newGraph)
 {
-  kDebug();
+  qCDebug(KGRAPHVIEWERLIB_LOG);
 
   // copy global graph render operations and attributes
   DotRenderOpVec ops;
   // decrease mem peak
   setRenderOperations(ops);
 
-  if (agget(newGraph, (char*)"_draw_") != NULL)
+  if (agget(newGraph, (char*)"_draw_"))
   {
     parse_renderop(agget(newGraph, (char*)"_draw_"), ops);
-    kDebug() << "_draw_: element renderOperations size is now " << ops.size();
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "_draw_: element renderOperations size is now " << ops.size();
   }
-  if (agget(newGraph, (char*)"_ldraw_") != NULL)
+  if (agget(newGraph, (char*)"_ldraw_"))
   {
     parse_renderop(agget(newGraph, (char*)"_ldraw_"), ops);
-    kDebug() << "_ldraw_: element renderOperations size is now " << ops.size();
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "_ldraw_: element renderOperations size is now " << ops.size();
   }
 
   setRenderOperations(ops);
 
-  Agsym_t *attr = agnxtattr(newGraph, AGRAPH, NULL);
+  Agsym_t *attr = agnxtattr(newGraph, AGRAPH, nullptr);
   while(attr)
   {
-    kDebug() << agnameof(newGraph) << ":" << attr->name << agxget(newGraph,attr);
+    qCDebug(KGRAPHVIEWERLIB_LOG) << agnameof(newGraph) << ":" << attr->name << agxget(newGraph,attr);
     m_attributes[attr->name] = agxget(newGraph,attr);
     attr = agnxtattr(newGraph, AGRAPH, attr);
   }
@@ -421,91 +421,91 @@ void DotGraph::updateWithGraph(graph_t* newGraph)
   // copy subgraphs
   for (graph_t* sg = agfstsubg(newGraph); sg; sg = agnxtsubg(sg))
   {
-    kDebug() << "subgraph:" << agnameof(sg);
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "subgraph:" << agnameof(sg);
     if (subgraphs().contains(agnameof(sg)))
     {
-      kDebug() << "known";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "known";
       // ???
       //       nodes()[ngn->name]->setZ(ngn->z());
       subgraphs()[agnameof(sg)]->updateWithSubgraph(sg);
-      if (subgraphs()[agnameof(sg)]->canvasElement()!=0)
+      if (subgraphs()[agnameof(sg)]->canvasElement())
       {
         //         nodes()[ngn->id()]->canvasElement()->setGh(m_height);
       }
     }
     else
     {
-      kDebug() << "new";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "new";
       GraphSubgraph* newsg = new GraphSubgraph(sg);
-      //       kDebug() << "new created";
+      //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new created";
       subgraphs().insert(agnameof(sg), newsg);
-      //       kDebug() << "new inserted";
+      //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new inserted";
     }
 
   }
 
   // copy nodes
   node_t* ngn = agfstnode(newGraph);
-  kDebug() << "first node:" << (void*)ngn;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "first node:" << (void*)ngn;
   
-  while (ngn != NULL)
+  while (ngn)
 //   foreach (GraphNode* ngn, newGraph.nodes())
   {
-    kDebug() << "node " << agnameof(ngn);
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "node " << agnameof(ngn);
     if (nodes().contains(agnameof(ngn)))
     {
-      kDebug() << "known";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "known";
 // ???
 //       nodes()[ngn->name]->setZ(ngn->z());
       nodes()[agnameof(ngn)]->updateWithNode(ngn);
-      if (nodes()[agnameof(ngn)]->canvasElement()!=0)
+      if (nodes()[agnameof(ngn)]->canvasElement())
       {
         //         nodes()[ngn->id()]->canvasElement()->setGh(m_height);
       }
     }
     else
     {
-      kDebug() << "new";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "new";
       GraphNode* newgn = new GraphNode(ngn);
-      //       kDebug() << "new created";
+      //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new created";
       nodes().insert(agnameof(ngn), newgn);
-      //       kDebug() << "new inserted";
+      //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new inserted";
     }
 
     // copy node edges
     edge_t* nge = agfstout(newGraph, ngn);
-    while (nge != NULL)
+    while (nge)
     {
-//      kDebug() << "edge " << nge->id;
-      QString edgeName = QString(agnameof(aghead(nge))) + agnameof(agtail(nge));
+//      qCDebug(KGRAPHVIEWERLIB_LOG) << "edge " << nge->id;
+      const QString edgeName = QString::fromUtf8(agnameof(aghead(nge))) + QString::fromUtf8(agnameof(agtail(nge)));
       if (edges().contains(edgeName))
       {
-//        kDebug() << "edge known" << nge->id;
+//        () << "edge known" << nge->id;
 //         edges()[nge->name]->setZ(nge->z());
         edges()[edgeName]->updateWithEdge(nge);
-        if (edges()[edgeName]->canvasEdge()!=0)
+        if (edges()[edgeName]->canvasEdge())
         {
           //         edges()[nge->id()]->canvasEdge()->setGh(m_height);
         }
       }
       else
       {
-        kDebug() << "new edge" << edgeName;
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "new edge" << edgeName;
         {
           GraphEdge* newEdge = new GraphEdge();
           newEdge->setId(edgeName);
           newEdge->updateWithEdge(nge);
-          if (elementNamed(agnameof(agtail(nge))) == 0)
+          if (elementNamed(agnameof(agtail(nge))) == nullptr)
           {
             GraphNode* newgn = new GraphNode();
-            //       kDebug() << "new created";
+            //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new created";
             nodes().insert(agnameof(agtail(nge)), newgn);
           }
           newEdge->setFromNode(elementNamed(agnameof(agtail(nge))));
-          if (elementNamed(agnameof(aghead(nge))) == 0)
+          if (elementNamed(agnameof(aghead(nge))) == nullptr)
           {
             GraphNode* newgn = new GraphNode();
-            //       kDebug() << "new created";
+            //       qCDebug(KGRAPHVIEWERLIB_LOG) << "new created";
             nodes().insert(agnameof(aghead(nge)), newgn);
           }
           newEdge->setToNode(elementNamed(agnameof(aghead(nge))));
@@ -516,14 +516,13 @@ void DotGraph::updateWithGraph(graph_t* newGraph)
     }
     ngn = agnxtnode(newGraph, ngn);
   }
-  kDebug() << "Done";
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "Done";
   emit readyToDisplay();
   computeCells();
 }
 
 void DotGraph::updateWithGraph(const DotGraph& newGraph)
 {
-  kDebug();
   GraphElement::updateWithElement(newGraph);
   m_width=newGraph.width();
   m_height=newGraph.height();
@@ -533,19 +532,19 @@ void DotGraph::updateWithGraph(const DotGraph& newGraph)
   computeCells();
   foreach (GraphSubgraph* nsg, newGraph.subgraphs())
   {
-    kDebug() << "subgraph" << nsg->id();
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "subgraph" << nsg->id();
     if (subgraphs().contains(nsg->id()))
     {
-      kDebug() << "subgraph known" << nsg->id();
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "subgraph known" << nsg->id();
       subgraphs().value(nsg->id())->updateWithSubgraph(*nsg);
-      if (subgraphs().value(nsg->id())->canvasElement()!=0)
+      if (subgraphs().value(nsg->id())->canvasElement())
       {
 //         subgraphs().value(nsg->id())->canvasElement()->setGh(m_height);
       }
     }
     else
     {
-      kDebug() << "new subgraph" << nsg->id();
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "new subgraph" << nsg->id();
       GraphSubgraph* newSubgraph = new GraphSubgraph();
       newSubgraph->updateWithSubgraph(*nsg);
       newSubgraph->setZ(0);
@@ -554,42 +553,42 @@ void DotGraph::updateWithGraph(const DotGraph& newGraph)
   }
   foreach (GraphNode* ngn, newGraph.nodes())
   {
-    kDebug() << "node " << ngn->id();
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "node " << ngn->id();
     if (nodes().contains(ngn->id()))
     {
-      kDebug() << "known";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "known";
       nodes()[ngn->id()]->setZ(ngn->z());
       nodes()[ngn->id()]->updateWithNode(*ngn);
-      if (nodes()[ngn->id()]->canvasElement()!=0)
+      if (nodes()[ngn->id()]->canvasElement())
       {
 //         nodes()[ngn->id()]->canvasElement()->setGh(m_height);
       }
     }
     else
     {
-      kDebug() << "new";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "new";
       GraphNode* newgn = new GraphNode(*ngn);
-//       kDebug() << "new created";
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "new created";
       nodes().insert(ngn->id(), newgn);
-//       kDebug() << "new inserted";
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "new inserted";
     }
   }
   foreach (GraphEdge* nge, newGraph.edges())
   {
-    kDebug() << "edge " << nge->id();
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "edge " << nge->id();
     if (edges().contains(nge->id()))
     {
-      kDebug() << "edge known" << nge->id();
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "edge known" << nge->id();
       edges()[nge->id()]->setZ(nge->z());
       edges()[nge->id()]->updateWithEdge(*nge);
-      if (edges()[nge->id()]->canvasEdge()!=0)
+      if (edges()[nge->id()]->canvasEdge())
       {
 //         edges()[nge->id()]->canvasEdge()->setGh(m_height);
       }
     }
     else
     {
-      kDebug() << "new edge" << nge->id();
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "new edge" << nge->id();
       {
         GraphEdge* newEdge = new GraphEdge();
         newEdge->setId(nge->id());
@@ -600,17 +599,17 @@ void DotGraph::updateWithGraph(const DotGraph& newGraph)
       }
     }
   }
-  kDebug() << "Done";
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "Done";
   computeCells();
 }
 
 void DotGraph::removeNodeNamed(const QString& nodeName)
 {
-  kDebug() << nodeName;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << nodeName;
   GraphNode* node = dynamic_cast<GraphNode*>(elementNamed(nodeName));
-  if (node == 0)
+  if (node == nullptr)
   {
-    kError() << "No such node " << nodeName;
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "No such node " << nodeName;
     return;
   }
   
@@ -622,7 +621,7 @@ void DotGraph::removeNodeNamed(const QString& nodeName)
         || it.value()->toNode() == node )
     {
       GraphEdge* edge = it.value();
-      if (edge->canvasEdge() != 0)
+      if (edge->canvasEdge())
       {
         edge->canvasEdge()->hide();
         delete edge->canvasEdge();
@@ -636,11 +635,11 @@ void DotGraph::removeNodeNamed(const QString& nodeName)
     }
   }
 
-  if (node->canvasNode() != 0)
+  if (node->canvasNode())
   {
     node->canvasNode()->hide();
     delete node->canvasNode();
-    node->setCanvasNode(0);
+    node->setCanvasNode(nullptr);
   }
   nodes().remove(nodeName);
   delete node;
@@ -651,18 +650,18 @@ void DotGraph::removeNodeFromSubgraph(
     const QString& nodeName,
     const QString& subgraphName)
 {
-  kDebug() << nodeName << subgraphName;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << nodeName << subgraphName;
   GraphNode* node = dynamic_cast<GraphNode*>(elementNamed(nodeName));
-  if (node == 0)
+  if (node == nullptr)
   {
-    kError() << "No such node " << nodeName;
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "No such node " << nodeName;
     return;
   }
 
   GraphSubgraph* subgraph = subgraphs()[subgraphName];
-  if (subgraph == 0)
+  if (subgraph == nullptr)
   {
-    kError() << "No such subgraph " << subgraphName;
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "No such subgraph " << subgraphName;
     return;
   }
   
@@ -675,12 +674,12 @@ void DotGraph::removeNodeFromSubgraph(
 
 void DotGraph::removeSubgraphNamed(const QString& subgraphName)
 {
-  kDebug() << subgraphName << " from " << subgraphs().keys();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << subgraphName << " from " << subgraphs().keys();
   GraphSubgraph* subgraph = subgraphs()[subgraphName];
 
-  if (subgraph == 0)
+  if (subgraph == nullptr)
   {
-    kError() << "Subgraph" << subgraphName << "not found";
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "Subgraph" << subgraphName << "not found";
     return;
   }
   GraphEdgeMap::iterator it, it_end;
@@ -691,7 +690,7 @@ void DotGraph::removeSubgraphNamed(const QString& subgraphName)
         || it.value()->toNode() == subgraph )
     {
       GraphEdge* edge = it.value();
-      if (edge->canvasEdge() != 0)
+      if (edge->canvasEdge())
       {
         edge->canvasEdge()->hide();
         delete edge->canvasEdge();
@@ -705,26 +704,26 @@ void DotGraph::removeSubgraphNamed(const QString& subgraphName)
     }
   }
 
-  if (subgraph->canvasSubgraph() != 0)
+  if (subgraph->canvasSubgraph())
   {
     subgraph->canvasSubgraph()->hide();
     delete subgraph->canvasSubgraph();
-    subgraph->setCanvasSubgraph(0);
+    subgraph->setCanvasSubgraph(nullptr);
   }
   foreach(GraphElement* element, subgraph->content())
   {
-    if (dynamic_cast<GraphNode*>(element) != 0)
+    if (dynamic_cast<GraphNode*>(element))
     {
-      kDebug() << "Adding" << element->id() << "to main graph";
+      qCDebug(KGRAPHVIEWERLIB_LOG) << "Adding" << element->id() << "to main graph";
       nodes()[element->id()] = dynamic_cast<GraphNode*>(element);
     }
-    else if (dynamic_cast<GraphSubgraph*>(element) != 0)
+    else if (dynamic_cast<GraphSubgraph*>(element))
     {
       subgraphs()[element->id()] = dynamic_cast<GraphSubgraph*>(element);
     }
     else
     {
-      kError() << "Don't know how to handle" << element->id();
+      qCWarning(KGRAPHVIEWERLIB_LOG) << "Don't know how to handle" << element->id();
     }
   }
   subgraph->content().clear();
@@ -734,14 +733,14 @@ void DotGraph::removeSubgraphNamed(const QString& subgraphName)
 
 void DotGraph::removeEdge(const QString& id)
 {
-  kDebug() << id;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << id;
   GraphEdgeMap::iterator it = edges().begin();
   for (; it != edges().end(); it++)
   {
     GraphEdge* edge = it.value();
     if (edge->id() ==id)
     {
-      if (edge->canvasEdge() != 0)
+      if (edge->canvasEdge())
       {
         edge->canvasEdge()->hide();
         delete edge->canvasEdge();
@@ -755,7 +754,7 @@ void DotGraph::removeEdge(const QString& id)
 
 void DotGraph::removeElement(const QString& id)
 {
-  kDebug() << id;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << id;
   GraphNodeMap::const_iterator itN = nodes().constBegin();
   for (; itN != nodes().constEnd(); itN++)
   {
@@ -806,11 +805,11 @@ void DotGraph::setAttribute(const QString& elementId, const QString& attributeNa
 
 GraphElement* DotGraph::elementNamed(const QString& id)
 {
-  GraphElement* ret = 0;
-  if ((ret = m_nodesMap.value(id, 0))) {
+  GraphElement* ret = nullptr;
+  if ((ret = m_nodesMap.value(id, nullptr))) {
     return ret;
   }
-  if ((ret = m_edgesMap.value(id, 0))) {
+  if ((ret = m_edgesMap.value(id, nullptr))) {
     return ret;
   }
   foreach(GraphSubgraph* subGraph, m_subgraphsMap) {
@@ -818,51 +817,51 @@ GraphElement* DotGraph::elementNamed(const QString& id)
       return ret;
     }
   }
-  return 0;
+  return nullptr;
 }
 
 void DotGraph::setGraphAttributes(QMap<QString,QString> attribs)
 {
-  kDebug() << attribs;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs;
   attributes() = attribs;
 }
 
 
 void DotGraph::addNewNode(QMap<QString,QString> attribs)
 {
-  kDebug() << attribs;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs;
   GraphNode* newNode = new GraphNode();
   newNode->attributes() = attribs;
   nodes().insert(newNode->id(), newNode);
-  kDebug() << "node added as" << newNode->id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "node added as" << newNode->id();
 }
 
 void DotGraph::addNewSubgraph(QMap<QString,QString> attribs)
 {
-  kDebug() << attribs;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs;
   GraphSubgraph* newSG = new GraphSubgraph();
   newSG->attributes() = attribs;
   subgraphs()[newSG->id()] = newSG;
-  kDebug() << "subgraph added as" << newSG->id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "subgraph added as" << newSG->id();
 }
 
 void DotGraph::addNewNodeToSubgraph(QMap<QString,QString> attribs, QString subgraph)
 {
-  kDebug() << attribs << "to" << subgraph;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs << "to" << subgraph;
   GraphNode* newNode = new GraphNode();
   newNode->attributes() = attribs;
   subgraphs()[subgraph]->content().push_back(newNode);
 
-  kDebug() << "node added as" << newNode->id() << "in" << subgraph;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "node added as" << newNode->id() << "in" << subgraph;
 }
 
 void DotGraph::addExistingNodeToSubgraph(QMap<QString,QString> attribs,QString subgraph)
 {
-  kDebug() << attribs << "to" << subgraph;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs << "to" << subgraph;
   GraphNode* node = dynamic_cast<GraphNode*>(elementNamed(attribs["id"]));
-  if (node == 0)
+  if (node == nullptr)
   {
-    kError() << "No such node" << attribs["id"];
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "No such node" << attribs["id"];
     return;
   }
   if (nodes().contains(attribs["id"]))
@@ -870,13 +869,13 @@ void DotGraph::addExistingNodeToSubgraph(QMap<QString,QString> attribs,QString s
     nodes().remove(attribs["id"]);
     node->attributes() = attribs;
     subgraphs()[subgraph]->content().push_back(node);
-    kDebug() << "node " << node->id() << " added in " << subgraph;
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "node " << node->id() << " added in " << subgraph;
   }
   else
   {
     foreach(GraphSubgraph* gs, subgraphs())
     {
-      GraphElement* elt = 0;
+      GraphElement* elt = nullptr;
       foreach(GraphElement* element, gs->content())
       {
         if (element == node)
@@ -885,12 +884,12 @@ void DotGraph::addExistingNodeToSubgraph(QMap<QString,QString> attribs,QString s
           break;
         }
       }
-      if (elt != 0)
+      if (elt)
       {
-        kDebug() << "removing node " << elt->id() << " from " << gs->id();
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "removing node " << elt->id() << " from " << gs->id();
         gs->removeElement(elt);
         subgraphs()[subgraph]->content().push_back(elt);
-        kDebug() << "node " << elt->id() << " added in " << subgraph;
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "node " << elt->id() << " added in " << subgraph;
         break;
       }
     }
@@ -899,16 +898,16 @@ void DotGraph::addExistingNodeToSubgraph(QMap<QString,QString> attribs,QString s
 
 void DotGraph::moveExistingNodeToMainGraph(QMap<QString,QString> attribs)
 {
-  kDebug() << attribs;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << attribs;
   GraphNode* node = dynamic_cast<GraphNode*>(elementNamed(attribs["id"]));
-  if (node == 0)
+  if (node == nullptr)
   {
-    kError() << "No such node" << attribs["id"];
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "No such node" << attribs["id"];
     return;
   }
   else if (nodes().contains(attribs["id"]))
   {
-    kError() << "Node" << attribs["id"] << "already in main graph";
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "Node" << attribs["id"] << "already in main graph";
     return;
   }
   else
@@ -926,10 +925,10 @@ void DotGraph::moveExistingNodeToMainGraph(QMap<QString,QString> attribs)
       }
       if (found)
       {
-        kDebug() << "removing node " << node->id() << " from " << gs->id();
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "removing node " << node->id() << " from " << gs->id();
         gs->removeElement(node);
         nodes()[node->id()] = node;
-        kDebug() << "node " << node->id() << " moved to main graph";
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "node " << node->id() << " moved to main graph";
         break;
       }
     }
@@ -938,23 +937,23 @@ void DotGraph::moveExistingNodeToMainGraph(QMap<QString,QString> attribs)
 
 void DotGraph::addNewEdge(QString src, QString tgt, QMap<QString,QString> attribs)
 {
-  kDebug() << src << tgt << attribs;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << src << tgt << attribs;
   GraphEdge* newEdge = new GraphEdge();
   newEdge->attributes() = attribs;
   GraphElement* srcElement = elementNamed(src);
-  if (srcElement == 0)
+  if (srcElement == nullptr)
   {
     srcElement = elementNamed(QString("cluster_")+src);
   }
   GraphElement* tgtElement = elementNamed(tgt);
-  if (tgtElement == 0)
+  if (tgtElement == nullptr)
   {
     tgtElement = elementNamed(QString("cluster_")+tgt);
   }
   
-  if (srcElement == 0 || tgtElement == 0)
+  if (srcElement == nullptr || tgtElement == nullptr)
   {
-    kError() << src << "or" << tgt << "missing";
+    qCWarning(KGRAPHVIEWERLIB_LOG) << src << "or" << tgt << "missing";
     return;
   }
   if (attribs.contains("id"))
@@ -972,9 +971,8 @@ void DotGraph::addNewEdge(QString src, QString tgt, QMap<QString,QString> attrib
 
 void DotGraph::removeAttribute(const QString& nodeName, const QString& attribName)
 {
-  kDebug();
   GraphElement* element = elementNamed(nodeName);
-  if (element != 0)
+  if (element)
   {
     element->removeAttribute(attribName);
   }
@@ -984,7 +982,7 @@ void DotGraph::renameNode(const QString& oldNodeName, const QString& newNodeName
 {
   if (oldNodeName != newNodeName)
   {
-    kDebug() << "Renaming " << oldNodeName << " into " << newNodeName;
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "Renaming " << oldNodeName << " into " << newNodeName;
     GraphNode* node = nodes()[oldNodeName];
     nodes().remove(oldNodeName);
     node->setId(newNodeName);
@@ -994,7 +992,6 @@ void DotGraph::renameNode(const QString& oldNodeName, const QString& newNodeName
 
 QString DotGraph::backColor() const
 {
-  kDebug();
   if (m_attributes.find("bgcolor") != m_attributes.end())
   {
     return m_attributes["bgcolor"];
@@ -1007,5 +1004,3 @@ QString DotGraph::backColor() const
 
 
 }
-
-#include "dotgraph.moc"
